/*
 This file is part of GNU Taler
 (C) 2022 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

import { TranslatedString } from "@gnu-taler/taler-util";
import { Fragment, h, VNode } from "preact";
import { Amount } from "../../components/Amount.js";
import { LogoHeader } from "../../components/LogoHeader.js";
import { Part } from "../../components/Part.js";
import { Link, SubTitle, WalletAction } from "../../components/styled/index.js";
import { useTranslationContext } from "../../context/translation.js";
import { Button } from "../../mui/Button.js";
import { State } from "./index.js";

export function IgnoredView(state: State.Ignored): VNode {
  const { i18n } = useTranslationContext();
  return (
    <Fragment>
      <span>
        <i18n.Translate>You&apos;ve ignored the tip.</i18n.Translate>
      </span>
    </Fragment>
  );
}

export function ReadyView(state: State.Ready): VNode {
  const { i18n } = useTranslationContext();
  return (
    <Fragment>
      <section>
        <p>
          <i18n.Translate>The merchant is offering you a tip</i18n.Translate>
        </p>
        <Part
          title={i18n.str`Amount`}
          text={<Amount value={state.amount} />}
          kind="positive"
        />
        <Part
          title={i18n.str`Merchant URL`}
          text={state.merchantBaseUrl as TranslatedString}
          kind="neutral"
        />
        <Part
          title={i18n.str`Exchange`}
          text={state.exchangeBaseUrl as TranslatedString}
          kind="neutral"
        />
      </section>
      <section>
        <Button
          variant="contained"
          color="success"
          onClick={state.accept.onClick}
        >
          <i18n.Translate>
            Receive &nbsp; {<Amount value={state.amount} />}
          </i18n.Translate>
        </Button>
      </section>
    </Fragment>
  );
}

export function AcceptedView(state: State.Accepted): VNode {
  const { i18n } = useTranslationContext();
  return (
    <Fragment>
      <section>
        <i18n.Translate>
          Tip from <code>{state.merchantBaseUrl}</code> accepted. Check your
          transactions list for more details.
        </i18n.Translate>
      </section>
    </Fragment>
  );
}
